﻿using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;


namespace WeightedSummarySample
{
    public partial class Form1 : Form
    {
        #region Ctor
        public Form1()
        {
            InitializeComponent();
            ultraGrid1.DataSource = MakeDataTable();
        }
        #endregion

        #region Data
        private DataTable MakeDataTable()
        {
            DataTable objTable = new DataTable();
            DataRow objRow;

            DataTable with_1 = objTable;
            with_1.Columns.Add("A", Type.GetType("System.Int32"));
            with_1.Columns.Add("B", Type.GetType("System.Int32"));
            with_1.Columns.Add("A*B", Type.GetType("System.Int32"));

            for (int i = 1; i <= 20; i++)
            {
                objRow = with_1.NewRow();

                objRow[0] = i + 2;
                objRow[1] = i + 3;
                objRow[2] = Convert.ToInt32(objRow[0]) * Convert.ToInt32(objRow[1]);
                with_1.Rows.Add(objRow);
            }

            return objTable;
        }
        #endregion
        #region Event : Form_Load
        private void Form1_Load(object sender, EventArgs e)
        {
            //Settup for summaries.
            this.ultraGrid1.DisplayLayout.Override.AllowRowSummaries = AllowRowSummaries.True;
            this.ultraGrid1.DisplayLayout.Override.SummaryDisplayArea = SummaryDisplayAreas.Bottom;
        }
        #endregion

        #region Event : InitializeLayout
        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Grid.CalcManager = this.ultraCalcManager1; 
            //Add summary of (A*B) into column A summary.       
            e.Layout.Bands[0].Summaries.Add("sumarryKey", SummaryType.Formula, e.Layout.Bands[0].Columns["A"]);
            e.Layout.Bands[0].Summaries.Add("sumarryKey1", SummaryType.Sum, e.Layout.Bands[0].Columns["B"]);
            //Hide the A*B column.
            e.Layout.Bands[0].Columns["A*B"].Hidden = true;
            //Set the display format to be just the number 
            e.Layout.Bands[0].Summaries["sumarryKey"].Formula = "Sum([A])";
            e.Layout.Bands[0].Summaries["sumarryKey1"].DisplayFormat = "{0}";
            //Hide the SummaryFooterCaption row 
               e.Layout.Bands[0].Override.SummaryFooterCaptionVisible = Infragistics.Win.DefaultableBoolean.False;
            UltraGridBand band = e.Layout.Bands[0];
            UltraGridColumn column = band.Columns[0];

            SummarySettings summarySettings = band.Summaries.Add(
                SummaryType.Custom,
                new LiteralCustomSummaryCalculator("This is my summary"),
                column,
                SummaryPosition.UseSummaryPositionColumn,
                column
                );

            summarySettings.DisplayFormat = "{0}";

            column.PerformAutoResize(PerformAutoSizeType.AllRowsInBand);
            e.Layout.Bands[0].Columns[1].PerformAutoResize(PerformAutoSizeType.AllRowsInBand);
        }
        #endregion
      
    }
    internal class LiteralCustomSummaryCalculator : ICustomSummaryCalculator
    {
        private string text;
        public LiteralCustomSummaryCalculator(string text)
        {
            this.text = text;
        }
        #region ICustomSummaryCalculator Members

        void ICustomSummaryCalculator.AggregateCustomSummary(SummarySettings summarySettings, UltraGridRow row)
        {
        }

        void ICustomSummaryCalculator.BeginCustomSummary(SummarySettings summarySettings, RowsCollection rows)
        {
        }

        object ICustomSummaryCalculator.EndCustomSummary(SummarySettings summarySettings, RowsCollection rows)
        {
            return text;
        }

        #endregion
    }
}
